@@ -46,10 +46,11 @@ public:
 
 public slots:
     void loadSettings();
-
-private slots:
     void saveSettings();
 
+signals:
+    void settingsChanged();
+
 private:
     PowerManagementSettings mSettings;
     Ui::LidWatcherSettings *mUi;
