@@ -40,7 +40,7 @@
     </message>
     <message>
         <location filename="../batterywatchersettings.ui" line="121"/>
-        <location filename="../batterywatchersettings.cpp" line="104"/>
+        <location filename="../batterywatchersettings.cpp" line="109"/>
         <source>Preview</source>
         <translation>Vista previa</translation>
     </message>
@@ -95,12 +95,12 @@
         <translation>Batería con porcentaje</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.cpp" line="104"/>
+        <location filename="../batterywatchersettings.cpp" line="109"/>
         <source>built in</source>
         <translation>integrado</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.cpp" line="109"/>
+        <location filename="../batterywatchersettings.cpp" line="114"/>
         <source>Level: %1%</source>
         <translation>Nivel: %1&#xa0;%</translation>
     </message>
@@ -128,7 +128,7 @@
         <translation>En caso de inactividad, con batería:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="90"/>
+        <location filename="../idlenesswatchersettings.ui" line="93"/>
         <source>Battery Idle time:</source>
         <translation>Tiempo de inactividad de la batería:</translation>
     </message>
@@ -144,7 +144,7 @@
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="76"/>
-        <location filename="../idlenesswatchersettings.ui" line="110"/>
+        <location filename="../idlenesswatchersettings.ui" line="113"/>
         <location filename="../idlenesswatchersettings.ui" line="178"/>
         <source>mm:ss</source>
         <translation>mm:ss</translation>
@@ -161,22 +161,37 @@
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="63"/>
-        <location filename="../idlenesswatchersettings.ui" line="97"/>
+        <location filename="../idlenesswatchersettings.ui" line="100"/>
         <source>Minutes:Seconds (min: 01:30)</source>
         <translation>Minutos:Segundos (mínimo: 01:30)</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="185"/>
+        <location filename="../idlenesswatchersettings.ui" line="195"/>
         <source>Check backlight</source>
         <translation>Comprobar retroiluminación</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="192"/>
+        <location filename="../idlenesswatchersettings.ui" line="185"/>
         <source>On battery discharging </source>
         <translation>Al descargarse la batería </translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="208"/>
+        <source>Command to Turn off Monitor</source>
+        <translation>Comando para apagar monitor</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="214"/>
+        <source>Recommended command for:</source>
+        <translation>Comando recomendado para:</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="234"/>
+        <source>On Wayland, usually handled by compositor and app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="237"/>
         <source>Disable idleness checks when fullscreen</source>
         <translation>Deshabilitar las comprobaciones de inactividad en pantalla completa</translation>
     </message>
@@ -239,22 +254,22 @@
         <translation>Configuración de la gestión de energía</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="40"/>
+        <location filename="../mainwindow.cpp" line="43"/>
         <source>Battery</source>
         <translation>Batería</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="44"/>
+        <location filename="../mainwindow.cpp" line="50"/>
         <source>Lid</source>
         <translation>Tapa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="48"/>
+        <location filename="../mainwindow.cpp" line="57"/>
         <source>Idle</source>
         <translation>Inactividad</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="52"/>
+        <location filename="../mainwindow.cpp" line="64"/>
         <source>Power keys</source>
         <translation>Teclas de apagado</translation>
     </message>
@@ -287,7 +302,7 @@
         <translation>Acción de tecla de hibernación:</translation>
     </message>
     <message>
-        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <location filename="../powerkeyssettings.cpp" line="50"/>
         <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
         <translation>Nota: Bajo Wayland, las teclas de apagado son configuradas por el compositor.</translation>
     </message>
