@@ -50,7 +50,7 @@
     </message>
     <message>
         <location filename="../batterywatchersettings.ui" line="121"/>
-        <location filename="../batterywatchersettings.cpp" line="104"/>
+        <location filename="../batterywatchersettings.cpp" line="109"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
@@ -95,12 +95,12 @@
         <translation>Batterie avec pourcentage</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.cpp" line="104"/>
+        <location filename="../batterywatchersettings.cpp" line="109"/>
         <source>built in</source>
         <translation>intégré(e)</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.cpp" line="109"/>
+        <location filename="../batterywatchersettings.cpp" line="114"/>
         <source>Level: %1%</source>
         <translation>Niveau : %1%</translation>
     </message>
@@ -128,7 +128,7 @@
         <translation>En cas d&apos;inactivité sur batterie&#x202f;:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="90"/>
+        <location filename="../idlenesswatchersettings.ui" line="93"/>
         <source>Battery Idle time:</source>
         <translation>Temps d&apos;inactivité sur batterie&#x202f;:</translation>
     </message>
@@ -144,7 +144,7 @@
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="76"/>
-        <location filename="../idlenesswatchersettings.ui" line="110"/>
+        <location filename="../idlenesswatchersettings.ui" line="113"/>
         <location filename="../idlenesswatchersettings.ui" line="178"/>
         <source>mm:ss</source>
         <translation>mm:ss</translation>
@@ -161,22 +161,37 @@
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="63"/>
-        <location filename="../idlenesswatchersettings.ui" line="97"/>
+        <location filename="../idlenesswatchersettings.ui" line="100"/>
         <source>Minutes:Seconds (min: 01:30)</source>
         <translation>Minutes:Secondes (min&#xa0;: 01:30)</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="185"/>
+        <location filename="../idlenesswatchersettings.ui" line="195"/>
         <source>Check backlight</source>
         <translation>Vérifier le rétroéclairage</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="192"/>
+        <location filename="../idlenesswatchersettings.ui" line="185"/>
         <source>On battery discharging </source>
         <translation>Lorsque la batterie se décharge </translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="208"/>
+        <source>Command to Turn off Monitor</source>
+        <translation>Commande pour éteindre le moniteur</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="214"/>
+        <source>Recommended command for:</source>
+        <translation>Commande recommandée pour :</translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="234"/>
+        <source>On Wayland, usually handled by compositor and app</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../idlenesswatchersettings.ui" line="237"/>
         <source>Disable idleness checks when fullscreen</source>
         <translation>Désactiver les contrôles d&apos;inactivité en plein écran</translation>
     </message>
@@ -239,22 +254,22 @@
         <translation>Paramètres de gestion de l&apos;alimentation</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="40"/>
+        <location filename="../mainwindow.cpp" line="43"/>
         <source>Battery</source>
         <translation>Batterie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="44"/>
+        <location filename="../mainwindow.cpp" line="50"/>
         <source>Lid</source>
         <translation>Capot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="48"/>
+        <location filename="../mainwindow.cpp" line="57"/>
         <source>Idle</source>
         <translation>Inactivité</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="52"/>
+        <location filename="../mainwindow.cpp" line="64"/>
         <source>Power keys</source>
         <translation>Boutons d&apos;alimentation</translation>
     </message>
@@ -287,7 +302,7 @@
         <translation>Action de la touche hiberner :</translation>
     </message>
     <message>
-        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <location filename="../powerkeyssettings.cpp" line="50"/>
         <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
         <translation>Note&#xa0;: Sous Wayland, les touches d&apos;alimentation sont configurées par le compositeur.</translation>
     </message>
